@@ -1,4 +1,4 @@
-/* $Id: directory-handle.cc,v 1.2 2003/04/30 18:25:18 murrayc Exp $ */               
+/* $Id: directory-handle.cc,v 1.8 2003/07/18 04:53:54 mxpxpod Exp $ */               
 
 /* Copyright 2003 gnome-vfsmm Development Team
  *
@@ -18,6 +18,8 @@
  */
 
 #include <libgnomevfsmm/directory-handle.h>
+#include <libgnomevfsmm/private.h>
+
 #include <libgnomevfs/gnome-vfs-directory.h>
 
 namespace
@@ -56,7 +58,7 @@ gboolean SignalProxy_Visit::c_callback(const gchar* rel_path, GnomeVFSFileInfo*
   {
     bool bRecurse = false;
     Glib::ustring strTemp = Glib::convert_const_gchar_ptr_to_ustring(rel_path);
-    bResult = (self->slot_)(strTemp, Glib::wrap(info), recursing_will_loop, bRecurse);
+    bResult = (self->slot_)(strTemp, Glib::wrap(info, true /* take_copy */), recursing_will_loop, bRecurse);
     *recurse = bRecurse;
   }
   catch(...)
@@ -143,13 +145,25 @@ void DirectoryHandle::visit(const Glib::RefPtr<const Uri>& uri, FileInfoOptions
   handle_result(result);
 }
  
-
-
-
-void DirectoryHandle::handle_result(GnomeVFSResult result) throw(exception)
+void DirectoryHandle::visit_files(const Glib::ustring& uri, const Glib::ListHandle<Glib::ustring>& file_list, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot) throw(exception)
 {
-  if(result != GNOME_VFS_OK)
-    throw exception(result);
+  SignalProxy_Visit proxy(slot);
+  GnomeVFSResult result = gnome_vfs_directory_visit_files(uri.c_str(), file_list.data(), static_cast<GnomeVFSFileInfoOptions>(info_options), static_cast<GnomeVFSDirectoryVisitOptions>(visit_options), &SignalProxy_Visit::c_callback, &proxy);
+  handle_result(result);
+}
+
+void DirectoryHandle::visit_files(const Glib::RefPtr<const Uri>& uri, const Glib::ListHandle<Glib::ustring> & file_list, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot) throw(exception)
+{
+  SignalProxy_Visit proxy(slot);
+   GnomeVFSResult result = gnome_vfs_directory_visit_files_at_uri(const_cast<GnomeVFSURI*>(uri->gobj()), file_list.data(), static_cast<GnomeVFSFileInfoOptions>(info_options), static_cast<GnomeVFSDirectoryVisitOptions>(visit_options), &SignalProxy_Visit::c_callback, &proxy);
+  handle_result(result);
+}
+
+void DirectoryHandle::list_load(const Glib::ListHandle<Glib::ustring>& list, const Glib::ustring& text_uri, FileInfoOptions info_options) throw(exception)
+{
+  GList* temp_list = list.data();
+  GnomeVFSResult result = gnome_vfs_directory_list_load(&temp_list, text_uri.c_str(), static_cast<GnomeVFSFileInfoOptions>(info_options));
+  handle_result(result);
 }
   
 } //namespace Vfs
